import { BuildContext, BuiltTaskResult } from '@teambit/builder';
import { Compiler, CompilerMain, TranspileOpts, TranspileOutput } from '@teambit/compiler';
import { Logger } from '@teambit/logger';
import { BabelCompilerOptions } from './compiler-options';
export declare class BabelCompiler implements Compiler {
    readonly id: string;
    private logger;
    private compiler;
    private options;
    distDir: string;
    distGlobPatterns: string[];
    shouldCopyNonSupportedFiles: boolean;
    artifactName: string;
    constructor(id: string, logger: Logger, compiler: CompilerMain, options: BabelCompilerOptions);
    /**
     * compile one file on the workspace
     */
    transpileFile(fileContent: string, options: TranspileOpts): TranspileOutput;
    /**
     * compile multiple components on the capsules
     */
    build(context: BuildContext): Promise<BuiltTaskResult>;
    createTask(name?: string): import("@teambit/compiler/compiler.task").CompilerTask;
    private buildOneCapsule;
    /**
     * if it's not false, it searches for config files, which is probably not the expected behavior
     * here as the configuration is passed programmatically.
     * practically, when the configFile is not set, babel returns `null` for all files in the capsule
     */
    private setConfigFileFalse;
    getArtifactDefinition(): {
        generatedBy: string;
        name: string;
        globPatterns: string[];
    }[];
    /**
     * given a source file, return its parallel in the dists. e.g. index.ts => dist/index.js
     */
    getDistPathBySrcPath(srcPath: string): string;
    /**
     * whether babel is able to compile the given path
     */
    isFileSupported(filePath: string): boolean;
    displayConfig(): string;
    private replaceFileExtToJs;
}
